@@ -1,19 +1,15 @@
 
 import unittest
 import sys
-
-if sys.version_info[0]==2:
-    from urllib2 import urlopen
-else:
-    from urllib.request import urlopen
+from urllib.request import urlopen
 
 import shorttext
 
+
 class TestSpellCheck(unittest.TestCase):
     def setUp(self):
         self.text = urlopen('http://norvig.com/big.txt').read()
-        if sys.version_info[0]==3:
-            self.text = self.text.decode('utf-8')
+        self.text = self.text.decode('utf-8')
 
     def tearDown(self):
         pass
